==> ejc-cost-api-3.0.0-20240204.085325-300-sources.jar: com/ejianc/business/target/vo/TargetCostFinishVO.java <==
package com.ejianc.business.target.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 目标成本完工统计
 * 
 * @author generator
 * 
 */
public class TargetCostFinishVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long budgetId; // 预算
    private String budgetName; // 预算
    private String billCode; // 单据编号
    private Long orgId; // 组织主键
    private String orgName; // 组织名称
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private Long employeeId; // 经办人
    private String employeeName; // 经办人
    private Long departmentId; // 经办人部门
    private String departmentName; // 经办人部门
    private BigDecimal budgetTaxMny; // 预算总金额
    @JsonFormat(
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private Date billDate; // 统计日期
    private BigDecimal laborTaxMny; // 本期人工费
    private BigDecimal materialTaxMny; // 本期材料费
    private BigDecimal majorTaxMny; // 本期专业分包费
    private BigDecimal mechanicalTaxMny; // 本期机械费
    private BigDecimal indirectionTaxMny; // 本期间接费
    private BigDecimal finishTaxMny; // 本期完工总金额
    private BigDecimal sumFinishTaxMny; // 累计完工总金额
    private Integer billState; // 单据状态
    private String remark; // 备注
    
    private List<TargetCostFinishDetailVO> targetCostFinishDetailList = new ArrayList<>(); // 目标成本完工统计明细

    @ReferSerialTransfer(referCode="cost-budgetProjectPro")
    public Long getBudgetId() {
        return budgetId;
    }

    @ReferDeserialTransfer
    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }

    public String getBudgetName() {
        return budgetName;
    }

    public void setBudgetName(String budgetName) {
        this.budgetName = budgetName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    @ReferSerialTransfer(referCode="idm-org")
    public Long getOrgId() {
        return orgId;
    }

    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public BigDecimal getBudgetTaxMny() {
        return budgetTaxMny;
    }

    public void setBudgetTaxMny(BigDecimal budgetTaxMny) {
        this.budgetTaxMny = budgetTaxMny;
    }
    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }
    public BigDecimal getLaborTaxMny() {
        return laborTaxMny;
    }

    public void setLaborTaxMny(BigDecimal laborTaxMny) {
        this.laborTaxMny = laborTaxMny;
    }
    public BigDecimal getMaterialTaxMny() {
        return materialTaxMny;
    }

    public void setMaterialTaxMny(BigDecimal materialTaxMny) {
        this.materialTaxMny = materialTaxMny;
    }
    public BigDecimal getMajorTaxMny() {
        return majorTaxMny;
    }

    public void setMajorTaxMny(BigDecimal majorTaxMny) {
        this.majorTaxMny = majorTaxMny;
    }
    public BigDecimal getMechanicalTaxMny() {
        return mechanicalTaxMny;
    }

    public void setMechanicalTaxMny(BigDecimal mechanicalTaxMny) {
        this.mechanicalTaxMny = mechanicalTaxMny;
    }
    public BigDecimal getIndirectionTaxMny() {
        return indirectionTaxMny;
    }

    public void setIndirectionTaxMny(BigDecimal indirectionTaxMny) {
        this.indirectionTaxMny = indirectionTaxMny;
    }
    public BigDecimal getFinishTaxMny() {
        return finishTaxMny;
    }

    public void setFinishTaxMny(BigDecimal finishTaxMny) {
        this.finishTaxMny = finishTaxMny;
    }
    public BigDecimal getSumFinishTaxMny() {
        return sumFinishTaxMny;
    }

    public void setSumFinishTaxMny(BigDecimal sumFinishTaxMny) {
        this.sumFinishTaxMny = sumFinishTaxMny;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
     public List<TargetCostFinishDetailVO> getTargetCostFinishDetailList() {
        return targetCostFinishDetailList;
     }

     public void setTargetCostFinishDetailList(List<TargetCostFinishDetailVO> targetCostFinishDetailList) {
        this.targetCostFinishDetailList = targetCostFinishDetailList;
     }
}

==> ejc-cost-api-3.0.0-20240422.024853-335-sources.jar: com/ejianc/business/target/vo/TargetCostFinishVO.java <==
package com.ejianc.business.target.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 目标成本完工统计
 * 
 * @author generator
 * 
 */
public class TargetCostFinishVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long budgetId; // 预算
    private String budgetName; // 预算
    private String billCode; // 单据编号
    private Long orgId; // 组织主键
    private String orgName; // 组织名称
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private Long employeeId; // 经办人
    private String employeeName; // 经办人
    private Long departmentId; // 经办人部门
    private String departmentName; // 经办人部门
    private BigDecimal budgetTaxMny; // 预算总金额
    @JsonFormat(
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private Date billDate; // 统计日期
    private BigDecimal laborTaxMny; // 本期人工费
    private BigDecimal materialTaxMny; // 本期材料费
    private BigDecimal majorTaxMny; // 本期专业分包费
    private BigDecimal mechanicalTaxMny; // 本期机械费
    private BigDecimal indirectionTaxMny; // 本期间接费
    private BigDecimal finishTaxMny; // 本期完工总金额
    private BigDecimal sumFinishTaxMny; // 累计完工总金额(不含本期)
    private BigDecimal sumFinishTaxMnyEndthis; // 累计完成合价
    private Integer billState; // 单据状态
    private String remark; // 备注
    
    private List<TargetCostFinishDetailVO> targetCostFinishDetailList = new ArrayList<>(); // 目标成本完工统计明细

    public BigDecimal getSumFinishTaxMnyEndthis() {
        return sumFinishTaxMnyEndthis;
    }

    public void setSumFinishTaxMnyEndthis(BigDecimal sumFinishTaxMnyEndthis) {
        this.sumFinishTaxMnyEndthis = sumFinishTaxMnyEndthis;
    }

    @ReferSerialTransfer(referCode="cost-budgetProjectPro")
    public Long getBudgetId() {
        return budgetId;
    }

    @ReferDeserialTransfer
    public void setBudgetId(Long budgetId) {
        this.budgetId = budgetId;
    }

    public String getBudgetName() {
        return budgetName;
    }

    public void setBudgetName(String budgetName) {
        this.budgetName = budgetName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }

    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public BigDecimal getBudgetTaxMny() {
        return budgetTaxMny;
    }

    public void setBudgetTaxMny(BigDecimal budgetTaxMny) {
        this.budgetTaxMny = budgetTaxMny;
    }
    public Date getBillDate() {
        return billDate;
    }

    public void setBillDate(Date billDate) {
        this.billDate = billDate;
    }
    public BigDecimal getLaborTaxMny() {
        return laborTaxMny;
    }

    public void setLaborTaxMny(BigDecimal laborTaxMny) {
        this.laborTaxMny = laborTaxMny;
    }
    public BigDecimal getMaterialTaxMny() {
        return materialTaxMny;
    }

    public void setMaterialTaxMny(BigDecimal materialTaxMny) {
        this.materialTaxMny = materialTaxMny;
    }
    public BigDecimal getMajorTaxMny() {
        return majorTaxMny;
    }

    public void setMajorTaxMny(BigDecimal majorTaxMny) {
        this.majorTaxMny = majorTaxMny;
    }
    public BigDecimal getMechanicalTaxMny() {
        return mechanicalTaxMny;
    }

    public void setMechanicalTaxMny(BigDecimal mechanicalTaxMny) {
        this.mechanicalTaxMny = mechanicalTaxMny;
    }
    public BigDecimal getIndirectionTaxMny() {
        return indirectionTaxMny;
    }

    public void setIndirectionTaxMny(BigDecimal indirectionTaxMny) {
        this.indirectionTaxMny = indirectionTaxMny;
    }
    public BigDecimal getFinishTaxMny() {
        return finishTaxMny;
    }

    public void setFinishTaxMny(BigDecimal finishTaxMny) {
        this.finishTaxMny = finishTaxMny;
    }
    public BigDecimal getSumFinishTaxMny() {
        return sumFinishTaxMny;
    }

    public void setSumFinishTaxMny(BigDecimal sumFinishTaxMny) {
        this.sumFinishTaxMny = sumFinishTaxMny;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    
     public List<TargetCostFinishDetailVO> getTargetCostFinishDetailList() {
        return targetCostFinishDetailList;
     }

     public void setTargetCostFinishDetailList(List<TargetCostFinishDetailVO> targetCostFinishDetailList) {
        this.targetCostFinishDetailList = targetCostFinishDetailList;
     }
}
